@@ -10,11 +10,7 @@ has '+ns'   => ( default => 'Pcore::Nginx' );
 
 has nginx_ver => ( is => 'lazy', isa => Str, init_arg => undef );
 
-our $CFG = {
-    NGINX => {    #
-        NGINX_VER => undef,
-    },
-};
+our $CFG = { nginx_ver => undef, };
 
 # CLI
 around CLI => sub ( $orig, $self ) {
@@ -26,7 +22,7 @@ around CLI => sub ( $orig, $self ) {
 };
 
 sub _build_nginx_ver ($self) {
-    return $self->cfg->{NGINX}->{NGINX_VER} || $ENV->dist('Pcore-Nginx')->cfg->{NGINX}->{NGINX_VER};
+    return $self->cfg->{nginx_ver} || $ENV->dist('Pcore-Nginx')->cfg->{nginx_ver};
 }
 
 # APP
@@ -124,7 +120,7 @@ around app_build => sub ( $orig, $self ) {
         # pcre
         $cv->begin;
         P->http->get(
-            qq[http://netcologne.dl.sourceforge.net/project/pcre/pcre/@{[$ENV->dist('Pcore-Nginx')->cfg->{NGINX}->{PCRE_VER}]}/pcre-@{[$ENV->dist('Pcore-Nginx')->cfg->{NGINX}->{PCRE_VER}]}.tar.gz],
+            qq[http://netcologne.dl.sourceforge.net/project/pcre/pcre/@{[$ENV->dist('Pcore-Nginx')->cfg->{pcre_ver}]}/pcre-@{[$ENV->dist('Pcore-Nginx')->cfg->{pcre_ver}]}.tar.gz],
             buf_size    => 1,
             on_progress => 1,
             on_finish   => sub ($res) {
@@ -177,7 +173,7 @@ around app_build => sub ( $orig, $self ) {
                 '--with-http_sub_module',
                 '--with-http_gzip_static_module',
                 '--with-http_perl_module',
-                '--with-pcre=' . $build_dir . 'pcre-' . $ENV->dist('Pcore-Nginx')->cfg->{NGINX}->{PCRE_VER},
+                '--with-pcre=' . $build_dir . 'pcre-' . $ENV->dist('Pcore-Nginx')->cfg->{pcre_ver},
                 '--with-pcre-jit',
                 map { '--add-module=' . $build_dir . $module->{$_}->{path} } grep { $module->{$_}->{enabled} } keys $module->%*,
             ) or die;
@@ -313,7 +309,7 @@ sub alien_proc ($self) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 140, 182             | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
+## |    3 | 136, 178             | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
